@@ -18,19 +18,19 @@ namespace stan {
       template<int R, int C>
       class LDLT_alloc : public chainable_alloc {
       public:
-        LDLT_alloc() : _N(0) {}
-        LDLT_alloc(const Eigen::Matrix<var,R,C> &A) : _N(0) {
+        LDLT_alloc() : N_(0) {}
+        LDLT_alloc(const Eigen::Matrix<var,R,C> &A) : N_(0) {
           compute(A);
         }
         
         inline void compute(const Eigen::Matrix<var,R,C> &A) {
           Eigen::Matrix<double,R,C> Ad(A.rows(),A.cols());
 
-          _N = A.rows();
+          N_ = A.rows();
           _variA.resize(A.rows(),A.cols());
 
-          for (size_t j = 0; j < _N; j++) {
-            for (size_t i = 0; i < _N; i++) {
+          for (size_t j = 0; j < N_; j++) {
+            for (size_t i = 0; i < N_; i++) {
               Ad(i,j) = A(i,j).val();
               _variA(i,j) = A(i,j).vi_;
             }
@@ -42,7 +42,7 @@ namespace stan {
           return _ldlt.vectorD().array().log().sum();
         }
         
-        size_t _N;
+        size_t N_;
         Eigen::LDLT< Eigen::Matrix<double,R,C> > _ldlt;
         Eigen::Matrix<vari*,R,C> _variA;
       };
@@ -78,8 +78,8 @@ namespace stan {
         return ret;
       }
       
-      inline size_t rows() const { return _alloc->_N; }
-      inline size_t cols() const { return _alloc->_N; }
+      inline size_t rows() const { return _alloc->N_; }
+      inline size_t cols() const { return _alloc->N_; }
       
       typedef size_t size_type;
 
@@ -102,11 +102,11 @@ namespace stan {
           Eigen::Matrix<double,R,C> invA;
           
           // If we start computing Jacobians, this may be a bit inefficient
-          invA.setIdentity(_alloc_ldlt->_N, _alloc_ldlt->_N);
+          invA.setIdentity(_alloc_ldlt->N_, _alloc_ldlt->N_);
           _alloc_ldlt->_ldlt.solveInPlace(invA);
 
-          for (size_t j = 0; j < _alloc_ldlt->_N; j++) {
-            for (size_t i = 0; i < _alloc_ldlt->_N; i++) {
+          for (size_t j = 0; j < _alloc_ldlt->N_; j++) {
+            for (size_t i = 0; i < _alloc_ldlt->N_; i++) {
               _alloc_ldlt->_variA(i,j)->adj_ += adj_ * invA(i,j);
             }
           }
@@ -121,14 +121,14 @@ namespace stan {
         virtual ~mdivide_left_ldlt_alloc() {}
         
         boost::shared_ptr< Eigen::LDLT< Eigen::Matrix<double,R1,C1> > > _ldltP;
-        Eigen::Matrix<double,R2,C2> _C;
+        Eigen::Matrix<double,R2,C2> C_;
       };
       
       template <int R1,int C1,int R2,int C2>
       class mdivide_left_ldlt_vv_vari : public vari {
       public:
-        int _M; // A.rows() = A.cols() = B.rows()
-        int _N; // B.cols()
+        int M_; // A.rows() = A.cols() = B.rows()
+        int N_; // B.cols()
         vari** _variRefB;
         vari** _variRefC;
         mdivide_left_ldlt_alloc<R1,C1,R2,C2> *_alloc;
@@ -137,8 +137,8 @@ namespace stan {
         mdivide_left_ldlt_vv_vari(const stan::math::LDLT_factor<var,R1,C1> &A,
                                   const Eigen::Matrix<var,R2,C2> &B)
         : vari(0.0),
-        _M(A.rows()),
-        _N(B.cols()),
+        M_(A.rows()),
+        N_(B.cols()),
         _variRefB((vari**)stan::agrad::memalloc_.alloc(sizeof(vari*) 
                                                        * B.rows() * B.cols())),
         _variRefC((vari**)stan::agrad::memalloc_.alloc(sizeof(vari*) 
@@ -147,45 +147,45 @@ namespace stan {
         _alloc_ldlt(A._alloc)
         {
           size_t pos = 0;
-          _alloc->_C.resize(_M,_N);
-          for (size_type j = 0; j < _N; j++) {
-            for (size_type i = 0; i < _M; i++) {
+          _alloc->C_.resize(M_,N_);
+          for (size_type j = 0; j < N_; j++) {
+            for (size_type i = 0; i < M_; i++) {
               _variRefB[pos] = B(i,j).vi_;
-              _alloc->_C(i,j) = B(i,j).val();
+              _alloc->C_(i,j) = B(i,j).val();
               pos++;
             }
           }
           
-          _alloc_ldlt->_ldlt.solveInPlace(_alloc->_C);
+          _alloc_ldlt->_ldlt.solveInPlace(_alloc->C_);
           
           pos = 0;
-          for (size_type j = 0; j < _N; j++) {
-            for (size_type i = 0; i < _M; i++) {
-              _variRefC[pos] = new vari(_alloc->_C(i,j),false);
+          for (size_type j = 0; j < N_; j++) {
+            for (size_type i = 0; i < M_; i++) {
+              _variRefC[pos] = new vari(_alloc->C_(i,j),false);
               pos++;
             }
           }
         }
         
         virtual void chain() {
-          Eigen::Matrix<double,R1,C1> adjA(_M,_M);
-          Eigen::Matrix<double,R2,C2> adjB(_M,_N);
+          Eigen::Matrix<double,R1,C1> adjA(M_,M_);
+          Eigen::Matrix<double,R2,C2> adjB(M_,N_);
           
           size_t pos = 0;
-          for (size_type j = 0; j < _N; j++)
-            for (size_type i = 0; i < _M; i++)
+          for (size_type j = 0; j < N_; j++)
+            for (size_type i = 0; i < M_; i++)
               adjB(i,j) = _variRefC[pos++]->adj_;
           
           _alloc_ldlt->_ldlt.solveInPlace(adjB);
-          adjA.noalias() = -adjB * _alloc->_C.transpose();
+          adjA.noalias() = -adjB * _alloc->C_.transpose();
 
-          for (size_type j = 0; j < _M; j++)
-            for (size_type i = 0; i < _M; i++)
+          for (size_type j = 0; j < M_; j++)
+            for (size_type i = 0; i < M_; i++)
               _alloc_ldlt->_variA(i,j)->adj_ += adjA(i,j);
           
           pos = 0;
-          for (size_type j = 0; j < _N; j++)
-            for (size_type i = 0; i < _M; i++)
+          for (size_type j = 0; j < N_; j++)
+            for (size_type i = 0; i < M_; i++)
               _variRefB[pos++]->adj_ += adjB(i,j);
         }
       };
@@ -193,8 +193,8 @@ namespace stan {
       template <int R1,int C1,int R2,int C2>
       class mdivide_left_ldlt_dv_vari : public vari {
       public:
-        int _M; // A.rows() = A.cols() = B.rows()
-        int _N; // B.cols()
+        int M_; // A.rows() = A.cols() = B.rows()
+        int N_; // B.cols()
         vari** _variRefB;
         vari** _variRefC;
         mdivide_left_ldlt_alloc<R1,C1,R2,C2> *_alloc;
@@ -202,8 +202,8 @@ namespace stan {
         mdivide_left_ldlt_dv_vari(const stan::math::LDLT_factor<double,R1,C1> &A,
                                   const Eigen::Matrix<var,R2,C2> &B)
         : vari(0.0),
-        _M(A.rows()),
-        _N(B.cols()),
+        M_(A.rows()),
+        N_(B.cols()),
         _variRefB((vari**)stan::agrad::memalloc_.alloc(sizeof(vari*) 
                                                        * B.rows() * B.cols())),
         _variRefC((vari**)stan::agrad::memalloc_.alloc(sizeof(vari*) 
@@ -214,29 +214,29 @@ namespace stan {
           using Eigen::Map;
           
           size_t pos = 0;
-          _alloc->_C.resize(_M,_N);
-          for (size_type j = 0; j < _N; j++) {
-            for (size_type i = 0; i < _M; i++) {
+          _alloc->C_.resize(M_,N_);
+          for (size_type j = 0; j < N_; j++) {
+            for (size_type i = 0; i < M_; i++) {
               _variRefB[pos] = B(i,j).vi_;
-              _alloc->_C(i,j) = B(i,j).val();
+              _alloc->C_(i,j) = B(i,j).val();
               pos++;
             }
           }
           
           _alloc->_ldltP = A._ldltP;
-          _alloc->_ldltP->solveInPlace(_alloc->_C);
+          _alloc->_ldltP->solveInPlace(_alloc->C_);
           
           pos = 0;
-          for (size_type j = 0; j < _N; j++) {
-            for (size_type i = 0; i < _M; i++) {
-              _variRefC[pos] = new vari(_alloc->_C(i,j),false);
+          for (size_type j = 0; j < N_; j++) {
+            for (size_type i = 0; i < M_; i++) {
+              _variRefC[pos] = new vari(_alloc->C_(i,j),false);
               pos++;
             }
           }
         }
         
         virtual void chain() {
-          Eigen::Matrix<double,R2,C2> adjB(_M,_N);
+          Eigen::Matrix<double,R2,C2> adjB(M_,N_);
           
           size_t pos = 0;
           for (size_type j = 0; j < adjB.cols(); j++)
@@ -255,8 +255,8 @@ namespace stan {
       template <int R1,int C1,int R2,int C2>
       class mdivide_left_ldlt_vd_vari : public vari {
       public:
-        int _M; // A.rows() = A.cols() = B.rows()
-        int _N; // B.cols()
+        int M_; // A.rows() = A.cols() = B.rows()
+        int N_; // B.cols()
         vari** _variRefC;
         mdivide_left_ldlt_alloc<R1,C1,R2,C2> *_alloc;
         const LDLT_alloc<R1,C1> *_alloc_ldlt;
@@ -264,35 +264,35 @@ namespace stan {
         mdivide_left_ldlt_vd_vari(const stan::math::LDLT_factor<var,R1,C1> &A,
                                   const Eigen::Matrix<double,R2,C2> &B)
           : vari(0.0),
-            _M(A.rows()),
-            _N(B.cols()),
+            M_(A.rows()),
+            N_(B.cols()),
             _variRefC((vari**)stan::agrad::memalloc_.alloc(sizeof(vari*) 
                                                            * B.rows() * B.cols())),
             _alloc(new mdivide_left_ldlt_alloc<R1,C1,R2,C2>()),
             _alloc_ldlt(A._alloc)
         {
-          _alloc->_C = B;
-          _alloc_ldlt->_ldlt.solveInPlace(_alloc->_C);
+          _alloc->C_ = B;
+          _alloc_ldlt->_ldlt.solveInPlace(_alloc->C_);
           
           size_t pos = 0;
-          for (size_type j = 0; j < _N; j++) {
-            for (size_type i = 0; i < _M; i++) {
-              _variRefC[pos] = new vari(_alloc->_C(i,j),false);
+          for (size_type j = 0; j < N_; j++) {
+            for (size_type i = 0; i < M_; i++) {
+              _variRefC[pos] = new vari(_alloc->C_(i,j),false);
               pos++;
             }
           }
         }
       
         virtual void chain() {
-          Eigen::Matrix<double,R1,C1> adjA(_M,_M);
-          Eigen::Matrix<double,R1,C2> adjC(_M,_N);
+          Eigen::Matrix<double,R1,C1> adjA(M_,M_);
+          Eigen::Matrix<double,R1,C2> adjC(M_,N_);
 
           size_t pos = 0;
           for (size_type j = 0; j < adjC.cols(); j++)
             for (size_type i = 0; i < adjC.rows(); i++)
               adjC(i,j) = _variRefC[pos++]->adj_;
         
-          adjA = -_alloc_ldlt->_ldlt.solve(adjC*_alloc->_C.transpose());
+          adjA = -_alloc_ldlt->_ldlt.solve(adjC*_alloc->C_.transpose());
 
           for (size_type j = 0; j < adjA.cols(); j++)
             for (size_type i = 0; i < adjA.rows(); i++)
@@ -367,40 +367,40 @@ namespace stan {
         inline void initializeB(const Eigen::Matrix<var,R3,C3> &B,bool haveD) { 
           Eigen::Matrix<double,R3,C3> Bd(B.rows(),B.cols());
           _variB.resize(B.rows(),B.cols());
-          for (size_t j = 0; j < B.cols(); j++) {
-            for (size_t i = 0; i < B.rows(); i++) {
+          for (int j = 0; j < B.cols(); j++) {
+            for (int i = 0; i < B.rows(); i++) {
               _variB(i,j) = B(i,j).vi_;
               Bd(i,j) = B(i,j).val();
             }
           }
-          _AinvB = _ldlt.solve(Bd);
+          AinvB_ = _ldlt.solve(Bd);
           if (haveD) 
-            _C.noalias() = Bd.transpose()*_AinvB;
+            C_.noalias() = Bd.transpose()*AinvB_;
           else
-            _value = (Bd.transpose()*_AinvB).trace();
+            _value = (Bd.transpose()*AinvB_).trace();
         }
         inline void initializeB(const Eigen::Matrix<double,R3,C3> &B,bool haveD) {
-          _AinvB = _ldlt.solve(B);
+          AinvB_ = _ldlt.solve(B);
           if (haveD) 
-            _C.noalias() = B.transpose()*_AinvB;
+            C_.noalias() = B.transpose()*AinvB_;
           else
-            _value = (B.transpose()*_AinvB).trace();
+            _value = (B.transpose()*AinvB_).trace();
         }
 
         template<int R1,int C1>
         inline void initializeD(const Eigen::Matrix<var,R1,C1> &D) {
-          _D.resize(D.rows(),D.cols());
+          D_.resize(D.rows(),D.cols());
           _variD.resize(D.rows(),D.cols());
           for (size_t j = 0; j < D.cols(); j++) {
             for (size_t i = 0; i < D.rows(); i++) {
               _variD(i,j) = D(i,j).vi_;
-              _D(i,j) = D(i,j).val();
+              D_(i,j) = D(i,j).val();
             }
           }
         }
         template<int R1,int C1>
         inline void initializeD(const Eigen::Matrix<double,R1,C1> &D) {
-          _D = D;
+          D_ = D;
         }
 
        public:
@@ -408,30 +408,30 @@ namespace stan {
         trace_inv_quad_form_ldlt_impl(const Eigen::Matrix<T1,R1,C1> &D,
                                       const stan::math::LDLT_factor<T2,R2,C2> &A,
                                       const Eigen::Matrix<T3,R3,C3> &B)
-        : _Dtype(boost::is_same<T1,var>::value?1:0),
+        : Dtype_(boost::is_same<T1,var>::value?1:0),
           _ldlt(A)
         {
           initializeB(B,true);
           initializeD(D);
           
-          _value = (_D*_C).trace();
+          _value = (D_*C_).trace();
         }
         
         trace_inv_quad_form_ldlt_impl(const stan::math::LDLT_factor<T2,R2,C2> &A,
                                       const Eigen::Matrix<T3,R3,C3> &B)
-        : _Dtype(2),
+        : Dtype_(2),
         _ldlt(A)
         {
           initializeB(B,false);
         }
         
-        const int _Dtype; // 0 = double, 1 = var, 2 = missing
+        const int Dtype_; // 0 = double, 1 = var, 2 = missing
         stan::math::LDLT_factor<T2,R2,C2> _ldlt;
-        Eigen::Matrix<double,Eigen::Dynamic,Eigen::Dynamic> _D;
+        Eigen::Matrix<double,Eigen::Dynamic,Eigen::Dynamic> D_;
         Eigen::Matrix<vari*,Eigen::Dynamic,Eigen::Dynamic> _variD;
         Eigen::Matrix<vari*,R3,C3> _variB;
-        Eigen::Matrix<double,R3,C3> _AinvB;
-        Eigen::Matrix<double,C3,C3> _C;
+        Eigen::Matrix<double,R3,C3> AinvB_;
+        Eigen::Matrix<double,C3,C3> C_;
         double _value;
       };
 
@@ -448,10 +448,10 @@ namespace stan {
         static inline void chainA(const double &adj,
                                   trace_inv_quad_form_ldlt_impl<var,R2,C2,T3,R3,C3> *impl) {
           Eigen::Matrix<double,R2,C2> aA;
-          if (impl->_Dtype != 2)
-            aA.noalias() = -adj*(impl->_AinvB*impl->_D.transpose()*impl->_AinvB.transpose());
+          if (impl->Dtype_ != 2)
+            aA.noalias() = -adj*(impl->AinvB_*impl->D_.transpose()*impl->AinvB_.transpose());
           else
-            aA.noalias() = -adj*(impl->_AinvB*impl->_AinvB.transpose());
+            aA.noalias() = -adj*(impl->AinvB_*impl->AinvB_.transpose());
           for (size_type j = 0; j < aA.cols(); j++)
             for (size_type i = 0; i < aA.rows(); i++)
               impl->_ldlt._alloc->_variA(i,j)->adj_ += aA(i,j);
@@ -459,10 +459,10 @@ namespace stan {
         static inline void chainB(const double &adj,
                                   trace_inv_quad_form_ldlt_impl<T2,R2,C2,var,R3,C3> *impl) {
           Eigen::Matrix<double,R3,C3> aB;
-          if (impl->_Dtype != 2)
-            aB.noalias() = adj*impl->_AinvB*(impl->_D + impl->_D.transpose());
+          if (impl->Dtype_ != 2)
+            aB.noalias() = adj*impl->AinvB_*(impl->D_ + impl->D_.transpose());
           else
-            aB.noalias() = adj*impl->_AinvB;
+            aB.noalias() = adj*impl->AinvB_;
           for (size_type j = 0; j < aB.cols(); j++)
             for (size_type i = 0; i < aB.rows(); i++)
               impl->_variB(i,j)->adj_ += aB(i,j);
@@ -482,10 +482,10 @@ namespace stan {
           
           chainB(adj_, _impl);
           
-          if (_impl->_Dtype == 1) {
+          if (_impl->Dtype_ == 1) {
             for (size_type j = 0; j < _impl->_variD.cols(); j++)
               for (size_type i = 0; i < _impl->_variD.rows(); i++)
-                _impl->_variD(i,j)->adj_ += adj_*_impl->_C(i,j);
+                _impl->_variD(i,j)->adj_ += adj_*_impl->C_(i,j);
           }
         }
 
