@@ -49,32 +49,35 @@
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::assignment,
                           (stan::gm::variable_dims, var_dims_)
-                          (stan::gm::expression, expr_) )
+                          (stan::gm::expression, expr_) );
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::variable_dims,
                           (std::string, name_)
-                          (std::vector<stan::gm::expression>, dims_) )
+                          (std::vector<stan::gm::expression>, dims_) );
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::distribution,
                           (std::string, family_)
-                          (std::vector<stan::gm::expression>, args_) )
+                          (std::vector<stan::gm::expression>, args_) );
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::for_statement,
                           (std::string, variable_)
                           (stan::gm::range, range_)
-                          (stan::gm::statement, statement_) )
+                          (stan::gm::statement, statement_) );
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::print_statement,
-                          (std::vector<stan::gm::printable>, printables_) )
+                          (std::vector<stan::gm::printable>, printables_) );
+
+BOOST_FUSION_ADAPT_STRUCT(stan::gm::increment_log_prob_statement,
+                          (stan::gm::expression, log_prob_))
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::sample,
                           (stan::gm::expression, expr_)
                           (stan::gm::distribution, dist_) 
-                          (stan::gm::range, truncation_) )
+                          (stan::gm::range, truncation_) );
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::statements,
                           (std::vector<stan::gm::var_decl>, local_decl_)
-                          (std::vector<stan::gm::statement>, statements_) )
+                          (std::vector<stan::gm::statement>, statements_) );
 
 namespace stan {
 
@@ -165,6 +168,11 @@ namespace stan {
           .get_result_type(function_name,arg_types,error_msgs)
           .is_primitive_double();
       }
+      static bool is_univariate(const expr_type& et) {
+        return et.num_dims_ == 0
+          && ( et.base_type_ == INT_T
+               || et.base_type_ == DOUBLE_T );
+      }
       bool operator()(const sample& s,
                       const variable_map& var_map,
                       std::ostream& error_msgs) const {
@@ -174,10 +182,6 @@ namespace stan {
           arg_types.push_back(s.dist_.args_[i].expression_type());
         std::string function_name(s.dist_.family_);
         function_name += "_log";
-        // expr_type result_type 
-        // = function_signatures::instance()
-        // .get_result_type(function_name,arg_types,error_msgs);
-        // if (!result_type.is_primitive_double()) {
         if (!is_double_return(function_name,arg_types,error_msgs)) {
           error_msgs << "unknown distribution=" << s.dist_.family_ << std::endl;
           return false;
@@ -199,11 +203,62 @@ namespace stan {
           error_msgs << function_name << "(...)";
           error_msgs << std::endl;
         }
+        // validate that variable and params are univariate if truncated
+        if (s.truncation_.has_low() || s.truncation_.has_high()) {
+          if (!is_univariate(s.expr_.expression_type())) { // .num_dims_ > 0) {
+            error_msgs << "Outcomes in truncated distributions must be univariate."
+                       << std::endl
+                       << "  Found outcome expression: ";
+            generate_expression(s.expr_,error_msgs);
+            error_msgs << std::endl
+                       << "  with non-univariate type: "
+                       << s.expr_.expression_type()
+                       << std::endl;
+            return false;
+          }
+          for (size_t i = 0; i < s.dist_.args_.size(); ++i)
+            if (!is_univariate(s.dist_.args_[i].expression_type())) { // .num_dims_ > 0) {
+              error_msgs << "Parameters in truncated distributions must be univariate."
+                         << std::endl
+                         << "  Found parameter expression: ";
+              generate_expression(s.dist_.args_[i],error_msgs);
+              error_msgs << std::endl
+                         << "  with non-univariate type: "
+                         << s.dist_.args_[i].expression_type()
+                         << std::endl;
+              return false;
+            }
+        }
+        if (s.truncation_.has_low()
+            && !is_univariate(s.truncation_.low_.expression_type())) {
+          error_msgs << "Lower boundsin truncated distributions must be univariate."
+                     << std::endl
+                     << "  Found lower bound expression: ";
+          generate_expression(s.truncation_.low_,error_msgs);
+          error_msgs << std::endl
+                     << "  with non-univariate type: "
+                     << s.truncation_.low_.expression_type()
+                     << std::endl;
+          return false;
+        }
+        if (s.truncation_.has_high() 
+            && !is_univariate(s.truncation_.high_.expression_type())) {
+          error_msgs << "Upper bounds in truncated distributions must be univariate."
+                     << std::endl
+                     << "  Found upper bound expression: ";
+          generate_expression(s.truncation_.high_,error_msgs);
+          error_msgs << std::endl
+                     << "  with non-univariate type: "
+                     << s.truncation_.high_.expression_type()
+                     << std::endl;
+          return false;
+        }
+
         if (s.truncation_.has_low()) {
           std::vector<expr_type> arg_types_trunc(arg_types);
           arg_types_trunc[0] = s.truncation_.low_.expression_type(); 
           std::string function_name_cdf(s.dist_.family_);
-          function_name_cdf += "_cdf";
+          function_name_cdf += "_cdf_log";
           if (!is_double_return(function_name_cdf,arg_types_trunc,error_msgs)) {
             error_msgs << "lower truncation not defined for specified arguments to "
                        << s.dist_.family_ << std::endl;
@@ -220,7 +275,7 @@ namespace stan {
           std::vector<expr_type> arg_types_trunc(arg_types);
           arg_types_trunc[0] = s.truncation_.high_.expression_type();
           std::string function_name_cdf(s.dist_.family_);
-          function_name_cdf += "_cdf";
+          function_name_cdf += "_cdf_log";
           if (!is_double_return(function_name_cdf,arg_types_trunc,error_msgs)) {
             error_msgs << "upper truncation not defined for specified arguments to "
                        << s.dist_.family_ << std::endl;
@@ -239,6 +294,34 @@ namespace stan {
     };
     boost::phoenix::function<validate_sample> validate_sample_f;
 
+    struct expression_as_statement {
+      template <typename T1, typename T2, typename T3>
+      struct result { typedef void type; };
+      void operator()(bool& pass,
+                      const stan::gm::expression& expr,
+                      std::stringstream& error_msgs) const {
+        error_msgs << "Illegal statement beginning with expression parsed as"
+                   << std::endl << "  ";
+        generate_expression(expr.expr_,error_msgs);
+        error_msgs << std::endl
+           << "Not a legal assignment or sampling statement.  Note that"
+           << std::endl
+           << "  * Assignment statements only allow variables (with optional indexes) on the left;"
+           << std::endl
+           << "    if you see an outer function logical_lt (<) with negated (-) second argument,"
+           << std::endl
+           << "    it indicates an assignment statement A <- B with illegal left"
+           << std::endl
+           << "    side A parsed as expression (A < (-B))."
+           << std::endl
+           << "  * Sampling statements allow arbitrary value-denoting expressions on the left."
+           << std::endl
+           << std::endl << std::endl;
+        pass = false;
+      }
+    };
+    boost::phoenix::function<expression_as_statement> expression_as_statement_f;
+
     struct unscope_locals {
       template <typename T1, typename T2>
       struct result { typedef void type; };
@@ -250,33 +333,6 @@ namespace stan {
     };
     boost::phoenix::function<unscope_locals> unscope_locals_f;
 
-    // struct add_conditional_condition {
-    //   template <typename T1, typename T2, typename T3>
-    //   struct result { typedef bool type; };
-    //   bool operator()(conditional_statement& cs,
-    //                   const expression& e,
-    //                   std::stringstream& error_msgs) const {
-    //     if (!e.expression_type().is_primitive()) {
-    //       error_msgs << "conditions in if-else statement must be primitive int or real;"
-    //                  << " found type=" << e.expression_type() << std::endl;
-    //       return false;
-    //     }
-    //     cs.conditions_.push_back(e);
-    //     return true;
-    //   }               
-    // };
-    // boost::phoenix::function<add_conditional_condition> add_conditional_condition_f;
-
-    // struct add_conditional_body {
-    //   template <typename T1, typename T2>
-    //   struct result { typedef void type; };
-    //   void operator()(conditional_statement& cs,
-    //                   const statement& s) const {
-    //     cs.bodies_.push_back(s);
-    //   }
-    // };
-    // boost::phoenix::function<add_conditional_body> add_conditional_body_f;
-
     struct add_while_condition {
       template <typename T1, typename T2, typename T3>
       struct result { typedef bool type; };
@@ -397,19 +453,19 @@ namespace stan {
       // set to true if sample_r are allowed
       statement_r.name("statement");
       statement_r
-        %= statement_seq_r(_r1,_r2)
-        | for_statement_r(_r1,_r2)
-        | while_statement_r(_r1,_r2)
-        | statement_2_g(_r1,_r2)
-        | print_statement_r(_r2)
-        | assignment_r(_r2)
-          [_pass 
-            = validate_assignment_f(_1,_r2,boost::phoenix::ref(var_map_),
-                                     boost::phoenix::ref(error_msgs_))]
-        | sample_r(_r1,_r2) [_pass = validate_sample_f(_1,
-                                               boost::phoenix::ref(var_map_),
-                                               boost::phoenix::ref(error_msgs_))]
-        | no_op_statement_r
+        %= no_op_statement_r                        // key ";"
+        | statement_seq_r(_r1,_r2)                  // key "{"
+        | increment_log_prob_statement_r(_r2)       // key "increment"
+        | for_statement_r(_r1,_r2)                  // key "for"
+        | while_statement_r(_r1,_r2)                // key "while"
+        | statement_2_g(_r1,_r2)                    // key "if"
+        | print_statement_r(_r2)                    // key "print"
+        | assignment_r(_r2)                         // lvalue "<-"
+        // [_pass = validate_assignment_f(_1,_r2,boost::phoenix::ref(var_map_),
+        // boost::phoenix::ref(error_msgs_))]
+        | sample_r(_r1,_r2)                         // expression "~"
+        | expression_g(_r2)                         // expression
+          [expression_as_statement_f(_pass,_1,boost::phoenix::ref(error_msgs_))]
         ;
 
       // _r1, _r2 same as statement_r
@@ -425,6 +481,15 @@ namespace stan {
       local_var_decls_r
         %= var_decls_g(false,local_origin); // - constants
 
+      increment_log_prob_statement_r.name("increment log prob statement");
+      increment_log_prob_statement_r
+        = lit("increment_log_prob")
+        > lit('(')
+        > expression_g(_r1)
+        > lit(')')
+        > lit(';') 
+        ;
+
       while_statement_r.name("while statement");
       while_statement_r
         = lit("while")
@@ -491,7 +556,9 @@ namespace stan {
         %= ( var_lhs_r(_r1)
              >> lit("<-") )
         > expression_g(_r1)
-        > lit(';') 
+        > lit(';')
+          [_pass = validate_assignment_f(_val,_r1,boost::phoenix::ref(var_map_),
+                                         boost::phoenix::ref(error_msgs_))]
         ;
 
       var_lhs_r.name("variable and array dimensions");
@@ -501,7 +568,7 @@ namespace stan {
 
       opt_dims_r.name("array dimensions (optional)");
       opt_dims_r 
-        %=  - dims_r(_r1);
+        %=  * dims_r(_r1);
 
       dims_r.name("array dimensions");
       dims_r 
@@ -518,12 +585,16 @@ namespace stan {
         %= ( expression_g(_r2)
              >> lit('~') )
         > eps
-        [_pass 
-         = validate_allow_sample_f(_r1,boost::phoenix::ref(error_msgs_))] 
+          [_pass = validate_allow_sample_f(_r1,
+                                           boost::phoenix::ref(error_msgs_))]
         > distribution_r(_r2)
         > -truncation_range_r(_r2)
-        > lit(';');
-
+        > lit(';')
+        > eps
+          [_pass = validate_sample_f(_val,
+                                     boost::phoenix::ref(var_map_),
+                                     boost::phoenix::ref(error_msgs_))]
+        ;
       distribution_r.name("distribution and parameters");
       distribution_r
         %= ( identifier_r
