@@ -48,19 +48,19 @@
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::index_op,
                           (stan::gm::expression, expr_)
                           (std::vector<std::vector<stan::gm::expression> >, 
-                           dimss_) )
+                           dimss_) );
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::fun,
                           (std::string, name_)
-                          (std::vector<stan::gm::expression>, args_) )
+                          (std::vector<stan::gm::expression>, args_) );
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::int_literal,
                           (int,val_)
-                          (stan::gm::expr_type,type_))
+                          (stan::gm::expr_type,type_));
 
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::double_literal,
                           (double,val_)
-                          (stan::gm::expr_type,type_) )
+                          (stan::gm::expr_type,type_) );
 
 
 
@@ -104,6 +104,17 @@ namespace stan {
                                                                     error_msgs);
 
         pass = !has_rng_suffix(fun.name_) || var_origin == derived_origin;
+        if (fun.name_ == "abs"
+            && fun.args_[0].expression_type().is_primitive_double()) {
+          error_msgs << "Warning: Function abs(real) is deprecated."
+                     << std::endl
+                     << "         It will be removed in a future release."
+                     << std::endl
+                     << "         Use fabs(real) instead."
+                     << std::endl << std::endl;
+        }
+
+
         if (!pass) {
           error_msgs << "random number generators only allowed in generated quantities block"
                      << "; found function=" << fun.name_
@@ -210,7 +221,8 @@ namespace stan {
           sft(f,error_msgs);
           return expression(f);
         }
-        fun f("divide_left",args);
+        fun f("divide_left",args); // this doesn't exist, so will
+                                   // throw error on purpose
         sft(f,error_msgs);
         return expression(f);
       }
@@ -362,6 +374,15 @@ namespace stan {
                      << std::endl;
           return var_expr;
         }
+        if (name == std::string("lp__")) {
+          error_msgs << std::endl
+                     << "WARNING:"
+                     << std::endl
+                     << "  Direct use of variable lp__ is deprecated and will be removed in a future release."
+                     << std::endl
+                     << "  Please use increment_log_prob(u) in place of of lp__ <- lp__ + u."
+                     << std::endl;
+        }
         pass = true;
         var_expr.set_type(vm.get_base_type(name),vm.get_num_dims(name));
         return var_expr;
