@@ -1,6 +1,7 @@
 #ifndef __STAN__IO__WRITER_HPP__
 #define __STAN__IO__WRITER_HPP__
 
+#include <stdexcept>
 #include <stan/prob/transform.hpp>
 
 namespace stan {
@@ -369,6 +370,54 @@ namespace stan {
           data_r_.push_back(uy[i]);
       }
 
+      /**
+       * Writes the unconstrained Cholesky factor corresponding to the
+       * specified constrained matrix.
+       *
+       * <p>The unconstraining operation is the inverse of the
+       * constraining operation in
+       * <code>cov_matrix_constrain(Matrix<T,Dynamic,Dynamic)</code>.
+       *
+       * @param y Constrained covariance matrix.
+       * @throw std::runtime_error if y has no elements or if it is not square
+       */
+      void cholesky_factor_unconstrain(matrix_t& y) {
+        // FIXME:  optimize by unrolling cholesky_factor_free
+        Eigen::Matrix<T,Eigen::Dynamic,1> y_free
+          = stan::prob::cholesky_factor_free(y);
+        for (int i = 0; i < y_free.size(); ++i)
+          data_r_.push_back(y_free[i]);
+      }
+
+
+      /**
+       * Writes the unconstrained covariance matrix corresponding
+       * to the specified constrained correlation matrix.
+       *
+       * <p>The unconstraining operation is the inverse of the
+       * constraining operation in
+       * <code>cov_matrix_constrain(Matrix<T,Dynamic,Dynamic)</code>.
+       *
+       * @param y Constrained covariance matrix.
+       * @throw std::runtime_error if y has no elements or if it is not square
+       */
+      void cov_matrix_unconstrain(matrix_t& y) {
+        typename matrix_t::size_type k = y.rows();
+        if (k == 0 || y.cols() != k)
+          BOOST_THROW_EXCEPTION(
+              std::runtime_error ("y must have elements and y must be a square matrix"));
+        typename matrix_t::size_type k_choose_2 = (k * (k-1)) / 2;
+        array_vec_t cpcs(k_choose_2);
+        array_vec_t sds(k);
+        bool successful = stan::prob::factor_cov_matrix(cpcs,sds,y);
+        if(!successful)
+          BOOST_THROW_EXCEPTION(std::runtime_error ("factor_cov_matrix failed"));
+        for (typename matrix_t::size_type i = 0; i < k_choose_2; ++i)
+          data_r_.push_back(cpcs[i]);
+        for (typename matrix_t::size_type i = 0; i < k; ++i)
+          data_r_.push_back(sds[i]);
+      }
+
       /**
        * Writes the unconstrained correlation matrix corresponding
        * to the specified constrained correlation matrix.
@@ -402,33 +451,6 @@ namespace stan {
           data_r_.push_back(cpcs[i]);
       }
 
-      /**
-       * Writes the unconstrained covariance matrix corresponding
-       * to the specified constrained correlation matrix.
-       *
-       * <p>The unconstraining operation is the inverse of the
-       * constraining operation in
-       * <code>cov_matrix_constrain(Matrix<T,Dynamic,Dynamic)</code>.
-       *
-       * @param y Constrained covariance matrix.
-       * @throw std::runtime_error if y has no elements or if it is not square
-       */
-      void cov_matrix_unconstrain(matrix_t& y) {
-        typename matrix_t::size_type k = y.rows();
-        if (k == 0 || y.cols() != k)
-          BOOST_THROW_EXCEPTION(
-              std::runtime_error ("y must have elements and y must be a square matrix"));
-        typename matrix_t::size_type k_choose_2 = (k * (k-1)) / 2;
-        array_vec_t cpcs(k_choose_2);
-        array_vec_t sds(k);
-        bool successful = stan::prob::factor_cov_matrix(cpcs,sds,y);
-        if(!successful)
-          BOOST_THROW_EXCEPTION(std::runtime_error ("factor_cov_matrix failed"));
-        for (typename matrix_t::size_type i = 0; i < k_choose_2; ++i)
-          data_r_.push_back(cpcs[i]);
-        for (typename matrix_t::size_type i = 0; i < k; ++i)
-          data_r_.push_back(sds[i]);
-      }
     };
   }
 
