@@ -10,6 +10,7 @@
 #include "stan/math/constants.hpp"
 #include "stan/math/functions/Phi.hpp"
 #include "stan/math/functions/Phi_approx.hpp"
+#include "stan/math/functions/abs.hpp"
 #include "stan/math/functions/as_bool.hpp"
 #include "stan/math/functions/bessel_first_kind.hpp"
 #include "stan/math/functions/bessel_second_kind.hpp"
@@ -64,7 +65,6 @@
 #include "stan/math/functions/multiply_log.hpp"
 #include "stan/math/functions/rising_factorial.hpp"
 #include "stan/math/functions/scaled_add.hpp"
-#include "stan/math/functions/softmax.hpp"
 #include "stan/math/functions/square.hpp"
 #include "stan/math/functions/step.hpp"
 #include "stan/math/functions/sub.hpp"
