@@ -3,14 +3,19 @@
 
 #include <stan/math/error_handling/matrix/constraint_tolerance.hpp>
 #include <stan/math/error_handling/matrix/check_size_match.hpp>
+#include <stan/math/error_handling/matrix/check_lower_triangular.hpp>
 #include <stan/math/error_handling/matrix/check_symmetric.hpp>
 #include <stan/math/error_handling/matrix/check_pos_definite.hpp>
+#include <stan/math/error_handling/matrix/check_pos_semidefinite.hpp>
+#include <stan/math/error_handling/matrix/check_cholesky_factor.hpp>
 #include <stan/math/error_handling/matrix/check_cov_matrix.hpp>
 #include <stan/math/error_handling/matrix/check_corr_matrix.hpp>
 #include <stan/math/error_handling/matrix/check_unit_vector.hpp>
 #include <stan/math/error_handling/matrix/check_simplex.hpp>
 #include <stan/math/error_handling/matrix/check_ordered.hpp>
 #include <stan/math/error_handling/matrix/check_positive_ordered.hpp>
+#include <stan/math/error_handling/matrix/check_spsd_matrix.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 #include <stan/math/error_handling/matrix/validate_non_negative_index.hpp>
 
 #endif
