@@ -27,9 +27,9 @@ namespace stan {
       void write_metric(std::ostream* o) {
         if(!o) return;
         *o << "# Elements of inverse mass matrix:" << std::endl;
-        for(size_t i = 0; i < mInv.rows(); ++i) {
+        for(int i = 0; i < mInv.rows(); ++i) {
           *o << "# " << mInv(i, 0) << std::flush;
-          for(size_t j = 1; j < mInv.cols(); ++j)
+          for(int j = 1; j < mInv.cols(); ++j)
             *o << ", " << mInv(i, j) << std::flush;
           *o << std::endl;
         }
