@@ -123,11 +123,12 @@ namespace stan {
             if (ahi < alo)
               d2 = -d2;
             alpha = ahi - (ahi - alo)*(ahiDFp + d2 - d1)/(ahiDFp - aloDFp + 2*d2);
-            if (alpha < std::min(alo,ahi)+0.01*std::fabs(alo-ahi) ||
+            if (!boost::math::isfinite(alpha) ||
+                alpha < std::min(alo,ahi)+0.01*std::fabs(alo-ahi) ||
                 alpha > std::max(alo,ahi)-0.01*std::fabs(alo-ahi))
               alpha = 0.5*(alo+ahi);
           }
-          
+
           newX = x + alpha*p;
           while (func(newX,newF,newDF)) {
             alpha = 0.5*(alpha+std::min(alo,ahi));
@@ -258,9 +259,29 @@ namespace stan {
 
       const Scalar &alpha0() const { return _alpha0; }
       const Scalar &alpha() const { return _alpha; }
+      const size_t iter_num() const { return _itNum; }
       
       const std::string &note() const { return _note; }
       
+      std::string get_code_string(int retCode) {
+        switch(retCode) {
+          case 0:
+            return std::string("Successful step completed");
+          case 1:
+            return std::string("Convergence detected: change in objective function was below tolerance");
+          case 2:
+            return std::string("Convergence detected: gradient norm is below tolerance");
+          case 3:
+            return std::string("Convergence detected: parameter change was below tolerance");
+          case 4:
+            return std::string("Maximum number of iterations hit, may not be at an optima");
+          case -1:
+            return std::string("Line search failed to achieve a sufficient decrease, no more progress can be made");
+          default:
+            return std::string("Unknown termination code");
+        }
+      }
+
       struct BFGSOptions {
         BFGSOptions() {
           maxIts = 10000;
@@ -271,6 +292,7 @@ namespace stan {
           alpha0 = 1e-3;
           tolX = 1e-8;
           tolF = 1e-8;
+          tolGrad = 1e-8;
         }
         size_t maxIts;
         Scalar rho;
@@ -280,6 +302,7 @@ namespace stan {
         Scalar minAlpha;
         Scalar tolX;
         Scalar tolF;
+        Scalar tolGrad;
       } _opts;
       
       
@@ -375,16 +398,19 @@ namespace stan {
         sk.noalias() = _xk - _xk_1;
         // Check for convergence
         if (std::fabs(_fk - _fk_1) < _opts.tolF) {
-          retCode = 1;
+          retCode = 1; // Objective function improvement wasn't sufficient
         }
-        else if (gradNorm < _opts.tolF) {
-          retCode = 2;
+        else if (gradNorm < _opts.tolGrad) {
+          retCode = 2; // Gradient norm was below threshold
         }
         else if (sk.norm() < _opts.tolX) {
-          retCode = 3;
+          retCode = 3; // Change in x was too small
+        }
+        else if (_itNum >= _opts.maxIts) {
+          retCode = 4; // Max number of iterations hit
         }
         else {
-          retCode = 0;
+          retCode = 0; // Step was successful more progress to be made
         }
         
         yk.noalias() = _gk - _gk_1;
@@ -434,6 +460,8 @@ namespace stan {
                           std::vector<double>& params_r,
                           std::vector<int>& params_i,
                           std::ostream* o = 0) {
+      // FIXME: is this supposed to return the log probability from the model?
+      return 0;
     }
 
     template <class M>
