@@ -147,8 +147,8 @@ namespace stan {
      * Calculates the chi square cumulative distribution function for the given
      * variate and degrees of freedom.
      * 
-     * @param y A scalar variate.
-     * @param nu Degrees of freedom.
+     * y A scalar variate.
+     * nu Degrees of freedom.
      * 
      * @return The cdf of the chi square distribution
      */
@@ -477,6 +477,18 @@ namespace stan {
                    RNG& rng) {
       using boost::variate_generator;
       using boost::random::chi_squared_distribution;
+
+      static const char* function = "stan::prob::chi_square_rng(%1%)";
+
+      using stan::math::check_positive;
+      using stan::math::check_finite;
+      
+      if (!check_finite(function, nu, "Degrees of freedom parameter"))
+        return 0;
+      if (!check_positive(function, nu, "Degrees of freedom parameter"))
+        return 0;
+    
+
       variate_generator<RNG&, chi_squared_distribution<> >
         chi_square_rng(rng, chi_squared_distribution<>(nu));
       return chi_square_rng();
