@@ -389,6 +389,19 @@ namespace stan {
                   RNG& rng) {
       using boost::variate_generator;
       using boost::random::lognormal_distribution;
+
+      static const char* function = "stan::prob::lognormal_rng(%1%)";
+
+      using stan::math::check_finite;
+      using stan::math::check_positive;
+
+      if (!check_finite(function, mu, "Location parameter"))
+        return 0;
+      if (!check_finite(function, sigma, "Scale parameter"))
+        return 0;
+      if (!check_positive(function, sigma, "Scale parameter"))
+        return 0;
+
       variate_generator<RNG&, lognormal_distribution<> >
         lognorm_rng(rng, lognormal_distribution<>(mu, sigma));
       return lognorm_rng();
