@@ -3,9 +3,14 @@
 #include <gtest/gtest.h>
 #include <boost/random/mersenne_twister.hpp>
 
-TEST(ProbDistributionsGumbel, random) {
+TEST(ProbDistributionsGumbel, error_check) {
   boost::random::mt19937 rng;
   EXPECT_NO_THROW(stan::prob::gumbel_rng(10.0,2.0,rng));
+
+  EXPECT_THROW(stan::prob::gumbel_rng(stan::math::positive_infinity(),2.0,rng),
+               std::domain_error);
+  EXPECT_THROW(stan::prob::gumbel_rng(10.0,-2,rng),std::domain_error);
+
 }
 
 TEST(ProbDistributionsGumbel, chiSquareGoodnessFitTest) {
