@@ -3,9 +3,17 @@
 #include <boost/random/mersenne_twister.hpp>
 #include<boost/math/distributions.hpp>
 
-TEST(ProbDistributionsLogNormal, random) {
+TEST(ProbDistributionsLogNormal, error_check) {
   boost::random::mt19937 rng;
   EXPECT_NO_THROW(stan::prob::lognormal_rng(2.0,1.0,rng));
+
+  EXPECT_THROW(stan::prob::lognormal_rng(2.0,-1.0,rng),std::domain_error);
+  EXPECT_THROW(stan::prob::lognormal_rng(2.0,stan::math::positive_infinity(),
+                                         rng),
+               std::domain_error);
+  EXPECT_THROW(stan::prob::lognormal_rng(stan::math::positive_infinity(),3,
+                                         rng),
+               std::domain_error);
 }
 
 TEST(ProbDistributionsLogNormal, chiSquareGoodnessFitTest) {
