@@ -3,9 +3,14 @@
 #include <boost/random/mersenne_twister.hpp>
 #include <boost/math/distributions.hpp>
 
-TEST(ProbDistributionsTruncNormal, random) {
+TEST(ProbDistributionsTruncNormal, error_check) {
   boost::random::mt19937 rng;
   EXPECT_NO_THROW(stan::prob::trunc_normal_rng(4.0,3.0,0.0,50.0,rng));
+
+  EXPECT_THROW(stan::prob::trunc_normal_rng(4.0,-3.0,0.0,50.0,rng),
+               std::domain_error);
+  EXPECT_THROW(stan::prob::trunc_normal_rng(4.0,3.0,60.0,50.0,rng),
+               std::domain_error);
 }
 
 TEST(ProbDistributionsTruncNormal, approxChiSquareGoodnessFitTest) {
