@@ -44,21 +44,15 @@ class TestBernoulli(unittest.TestCase):
 
     model = StanModel(model_code=bernoulli_model_code, model_name="bernoulli")
 
+    fit = model.sampling(data=bernoulli_data)
+
     def test_bernoulli_constructor(self):
         model = self.model
         self.assertEqual(model.model_name, "bernoulli")
         self.assertTrue(model.model_cppname.endswith("bernoulli"))
 
-    def test_bernoulli_compile_time(self):
-        model_code = self.bernoulli_model_code
-        t0 = time.time()
-        model = StanModel(model_code=model_code)
-        self.assertIsNotNone(model)
-        msg = "Compile time: {}s (vs. RStan 28s)\n".format(int(time.time()-t0))
-        logging.info(msg)
-
     def test_bernoulli_sampling(self):
-        fit = self.model.sampling(data=self.bernoulli_data)
+        fit = self.fit
         self.assertEqual(fit.sim['iter'], 2000)
         self.assertEqual(fit.sim['pars_oi'], ['theta', 'lp__'])
         self.assertEqual(len(fit.sim['samples']), 4)
@@ -82,7 +76,7 @@ class TestBernoulli(unittest.TestCase):
             fit = self.model.sampling(data=bad_data)
 
     def test_bernoulli_extract(self):
-        fit = self.model.sampling(data=self.bernoulli_data)
+        fit = self.fit
         extr = fit.extract(permuted=True)
         assert -7.4 < np.mean(extr['lp__']) < -7.0
         assert 0.1 < np.mean(extr['theta']) < 0.4
@@ -104,13 +98,18 @@ class TestBernoulli(unittest.TestCase):
         assert 0.1 < np.mean(extr[:, 0, 0]) < 0.4
 
     def test_bernoulli_summary(self):
-        fit = self.model.sampling(data=self.bernoulli_data)
+        fit = self.fit
         s = fit.summary()
         assert s is not None
         repr(fit)
         print(fit)
 
-    def test_bernoulli_sample_file(self):
+    def test_bernoulli_plot(self):
+        fit = self.fit
+        fig = fit.plot()
+        assert fig is not None
+
+    def test_bernoulli_sampling_sample_file(self):
         tmpdir = tempfile.mkdtemp()
         sample_file = os.path.join(tmpdir, 'sampling.csv')
         sample_file_base = os.path.splitext(os.path.basename(sample_file))[0]
@@ -120,8 +119,13 @@ class TestBernoulli(unittest.TestCase):
         fit = self.model.sampling(data=self.bernoulli_data, sample_file='/tmp/doesnotexist')
         assert fit is not None
 
-        tmpdir = tempfile.mkdtemp()
-        sample_file = 'opt.csv'
-        sample_file_base = os.path.splitext(os.path.basename(sample_file))[0]
-        fit = self.model.optimizing(data=self.bernoulli_data, sample_file=sample_file)
-        # not working right now -- it's a stan issue, not a pystan issue.
+    # FIXME: not working right now -- need to debug
+    # def test_bernoulli_optimizing_sample_file(self):
+    #     tmpdir = tempfile.mkdtemp()
+    #     sample_file = os.path.join(tmpdir, 'optim.csv')
+    #     sample_file_base = os.path.splitext(os.path.basename(sample_file))[0]
+    #     fit = self.model.optimizing(data=self.bernoulli_data, sample_file=sample_file)
+    #     assert all([sample_file_base in fn for fn in os.listdir(tmpdir)])
+
+    #     fit = self.model.optimizing(data=self.bernoulli_data, sample_file='/tmp/doesnotexist')
+    #     assert fit is not None
