@@ -1,10 +1,8 @@
-import time
 import unittest
 
-import numpy as np
-
 from pystan import StanModel
 
+
 class TestStanfit(unittest.TestCase):
 
     def test_init_zero_exception_inf_grad(self):
